@@ -735,7 +735,9 @@ void YahooContact::writeYABEntry()
 	setProperty( YahooProtocol::protocol()->propAdditionalNumber, m_YABEntry->additionalNumber );
 	setProperty( YahooProtocol::protocol()->propAltEmail1, m_YABEntry->altEmail1 );
 	setProperty( YahooProtocol::protocol()->propAltEmail2, m_YABEntry->altEmail2 );
+	setProperty( YahooProtocol::protocol()->propImAIM, m_YABEntry->imAIM );
 	setProperty( YahooProtocol::protocol()->propImICQ, m_YABEntry->imICQ );
+	setProperty( YahooProtocol::protocol()->propImMSN, m_YABEntry->imMSN );
 	setProperty( YahooProtocol::protocol()->propImGoogleTalk, m_YABEntry->imGoogleTalk );
 	setProperty( YahooProtocol::protocol()->propImSkype, m_YABEntry->imSkype );
 	setProperty( YahooProtocol::protocol()->propImIRC, m_YABEntry->imIRC );
@@ -796,7 +798,9 @@ void YahooContact::readYABEntry()
 	m_YABEntry->additionalNumber = property( YahooProtocol::protocol()->propAdditionalNumber ).value().toString();
 	m_YABEntry->altEmail1 = property( YahooProtocol::protocol()->propAltEmail1 ).value().toString();
 	m_YABEntry->altEmail2 = property( YahooProtocol::protocol()->propAltEmail2 ).value().toString();
+	m_YABEntry->imAIM = property( YahooProtocol::protocol()->propImAIM ).value().toString();
 	m_YABEntry->imICQ = property( YahooProtocol::protocol()->propImICQ ).value().toString();
+	m_YABEntry->imMSN = property( YahooProtocol::protocol()->propImMSN ).value().toString();
 	m_YABEntry->imGoogleTalk = property( YahooProtocol::protocol()->propImGoogleTalk ).value().toString();
 	m_YABEntry->imSkype = property( YahooProtocol::protocol()->propImSkype ).value().toString();
 	m_YABEntry->imIRC = property( YahooProtocol::protocol()->propImIRC ).value().toString();
